@@ -106,7 +106,6 @@ class Panda(QtGui.QMainWindow): #main class
 		self.ui.btnLove.setStyleSheet("background-image: url(:/img/img/thumbup_small.png);\nborder: rgb(0, 0, 0);\nbackground-color: rgb(100, 100, 100);")
 		self.ui.btnHate.setStyleSheet("background-color: rgb(100, 100, 100);\nborder: rgb(255, 255, 255);\nbackground-image: url(:/img/img/thumbdwn_small.png);")
 		self.player = RadioPlayer()
-		self.stimer.singleShot(50, self.player.start)
 		self.os = self.player.get_product()
 		if self.os != "RX-51": #check for N900
 			self.ui.albumArt.setStyleSheet("background-color: rgb(255, 255, 255);")
@@ -115,6 +114,7 @@ class Panda(QtGui.QMainWindow): #main class
 		self.player.format = self.c.format
 		self.player.protocol_version = int(self.c.protocol_version)
 		self.player.proxy = self.c.proxy
+		self.player.start()
 		if not self.c.lastplayed == "": #auto-play last station
 			self.autoPlay = self.c.lastplayed
 		else:
