@@ -21,8 +21,10 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 			from libpiano.OSSOBackend import OSSOBackend
 			self.player = OSSOBackend()
 		else:
-			from libpiano.MPlayerBackend import MPlayerBackend
-			self.player = MPlayerBackend()
+			#from libpiano.MPlayerBackend import MPlayerBackend
+			#self.player = MPlayerBackend()
+			from libpiano.OSSOBackend import OSSOBackend
+			self.player = OSSOBackend()
 
 		QtCore.QObject.connect(self.player, QtCore.SIGNAL("eof"), self.sigEOF)
 		QtCore.QObject.connect(self.player, QtCore.SIGNAL("state_change(int)"), self.stateChange)
@@ -30,6 +32,7 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 		self.format = 'aacplus'
 		self.protocol_version = 0
 		self.proxy = ""
+		self.pandora = 0
 
 		QtCore.QThread.__init__(self)
 
